Color

Struct Color 

#[repr(C)]
pub struct Color { pub r: f32, pub g: f32, pub b: f32, pub a: f32, }
An SRGB color.

Fields

r: f32

Red

g: f32

Green

b: f32

Blue

a: f32

Alpha

Implementations

Source

impl Color

pub const TRANSPARENT: Color

pub const BLACK: Color

pub const LIGHTGREY: Color

pub const DARKGREY: Color

pub const GREY: Color

pub const RED: Color

pub const ORANGE: Color

pub const GREEN: Color

pub const DARKGREEN: Color

pub const BLUE: Color

pub const LIGHTBLUE: Color

pub const WHITE: Color

pub const YELLOW: Color

pub const PURPLE: Color

pub const fn new(r: f32, g: f32, b: f32) -> Self

pub fn mix(self, other: Color, factor: f32) -> Self

pub fn from_hsv(hue: f64, saturation: f64, value: f64) -> Self

Converts values in HSV color space to RGB

  • hue: f64 - the position of the color on the color wheel. Between 0 and 360
  • saturation: f64 - how much color. Between 0, no color, and 1, all color
  • value: f64 - or lightness. Between 0, black, and 1, white
pub fn from_hex(hex: &str) -> Color

pub fn u8_srgb(r: u8, g: u8, b: u8) -> Self

creates colors from rgb and maps them into srgb space

srgb_color = ((rgb_color / 255 + 0.055) / 1.055) ^ 2.4

pub const fn alpha(self, a: f32) -> Self