pub struct ElementContext {
pub mouse_buttons: MouseButtonState,
pub scroll: f32,
pub cursor_pos: Vec2,
pub cursor_delta: Vec2,
pub hot_active: HotActiveElement,
}Fields
scroll: f32cursor_pos: Vec2cursor_delta: Vec2hot_active: HotActiveElementImplementations
Sourceimpl ElementContext
impl ElementContext
pub fn hot_active(&self, id: impl Into<ElementId>) -> HotActive
pub fn btn_hot_active(&mut self, id: impl Into<ElementId>) -> (HotActive, bool)
pub fn is_hovered(&self, id: impl Into<ElementId>) -> bool
Sourcepub fn any_element_with_id_hovered(&self) -> bool
pub fn any_element_with_id_hovered(&self) -> bool
useful for overlay ui in games, to not check for camera click raycasts into the scene ] if some part of the ui is hovered in front of it
pub fn get_computed_bounds( &self, id: impl Into<ElementId>, ) -> Option<ComputedBounds>
pub fn new() -> Self
pub fn set_input(&mut self, input: &Input)
Sourcepub fn set_input_scaled_to_fixed_height(
&mut self,
input: &Input,
screen_size: PhysicalSize<u32>,
fixed_height: f32,
)
pub fn set_input_scaled_to_fixed_height( &mut self, input: &Input, screen_size: PhysicalSize<u32>, fixed_height: f32, )
Use this, if we layout the UI always at a fixed height, but scale it up by some factor in the shader to match the actual screen resolution
input is taken at screen resolution.
screen_size is the actual screen resolution.
fixed_height is the height of our ui layout. (width is calculated to be proportional to the screen_size, both scaled up to screen_size in rendering later).
pub fn set_cursor_delta(&mut self, cursor_delta: Vec2)
pub fn set_cursor_pos(&mut self, cursor_pos: Vec2)
pub fn set_hot_active(&mut self, id: ElementId, state: HotActive)